@@ -1,6 +1,7 @@
 #define ERR_PRO_CANT_OPEN_FILE 1
 
 #include "pstring.h"
+#include "exprtool.h"
 
 typedef int flag;
 
@@ -13,6 +14,10 @@ typedef int (*is_variable_true_func) (struct tmplpro_param* param, PSTRING name)
 typedef int (*init_loop_func) (struct tmplpro_state* state, PSTRING name);
 typedef int (*next_loop_func) (struct tmplpro_state* state);
 typedef const char* (*find_file_func) (const char* filename, const char* prevfilename);
+typedef void (*init_expr_arglist_func) (struct tmplpro_param* param);
+typedef void (*push_expr_arglist_func) (struct tmplpro_param* param, struct exprval);
+typedef struct exprval (*call_expr_userfnc_func) (struct tmplpro_param* param, void* extfunc);
+typedef void* (*is_expr_userfnc_func) (struct tmplpro_param* param, PSTRING name);
 
 struct tmplpro_param {
   int global_vars;
@@ -30,12 +35,20 @@ struct tmplpro_param {
   int die_on_bad_params;
   /* int vanguard_compatibility_mode; */
   /* hooks to perl or other container */
+  /* HTML::Template hooks */
   writerfunc WriterFuncPtr;
   get_variable_func GetVarFuncPtr;
   is_variable_true_func IsVarTrueFuncPtr;
   init_loop_func InitLoopFuncPtr;
   next_loop_func NextLoopFuncPtr;
   find_file_func FindFileFuncPtr;
+  /* HTML::Template::Expr hooks */
+  init_expr_arglist_func InitExprArglistFuncPtr;
+  push_expr_arglist_func PushExprArglistFuncPtr;
+  call_expr_userfnc_func CallExprUserfncFuncPtr;
+  is_expr_userfnc_func   IsExprUserfncFuncPtr;
+  void* ExprFuncHash;
+  void* ExprFuncArglist;
   /* private */
   int cur_includes; /* internal counter of include depth */
   const char* selfpath; /* file that included this file or empty string */
@@ -62,6 +75,9 @@ int exec_tmpl_from_memory (PSTRING memarea, struct tmplpro_param* param);
 void procore_init();
 void procore_done();
 
+/* internal initialization of struct tmplpro_param */
+void param_init(struct tmplpro_param* param);
+
 void tag_warn  (struct tmplpro_state *state, char* message, PSTRING msg2);
 
 /* 
